Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(436)

Unified Diff: src/trusted/service_runtime/arch/arm/nacl_switch.S

Issue 10829110: Fix two register leaks in the trusted->untrusted context switch (Closed) Base URL: svn://svn.chromium.org/native_client/trunk/src/native_client
Patch Set: Fix comment Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « SConstruct ('k') | src/trusted/service_runtime/arch/x86_32/springboard.S » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/trusted/service_runtime/arch/arm/nacl_switch.S
diff --git a/src/trusted/service_runtime/arch/arm/nacl_switch.S b/src/trusted/service_runtime/arch/arm/nacl_switch.S
index 68dc305cab1b9906e0250218f4fb871e91697aaa..04b703c3ad32501a3bad6a67e841f73d4865aa69 100644
--- a/src/trusted/service_runtime/arch/arm/nacl_switch.S
+++ b/src/trusted/service_runtime/arch/arm/nacl_switch.S
@@ -22,13 +22,14 @@
DEFINE_GLOBAL_HIDDEN_IDENTIFIER(NaClSwitch):
/*
* We clear registers r2, r3, lr, flag and status fields in CPSR
* (status register) to avoid information leaks. The remaining
* registers are overwritten by the code that follows after.
*/
mov r2, #0
mov r3, #0
+ mov r12, #0
mov lr, #0
msr cpsr_fs, #0
« no previous file with comments | « SConstruct ('k') | src/trusted/service_runtime/arch/x86_32/springboard.S » ('j') | no next file with comments »
@@ -22,13 +22,14 @@
DEFINE_GLOBAL_HIDDEN_IDENTIFIER(NaClSwitch):
/*
- * We clear registers r2, r3, lr, flag and status fields in CPSR
- * (status register) to avoid information leaks. The remaining
+ * We clear registers r2, r3, r12 (ip), lr, flag and status fields in
+ * CPSR (status register) to avoid information leaks. The remaining
* registers are overwritten by the code that follows after.
*/

Powered by Google App Engine
This is Rietveld 408576698